@@ -5,12 +5,12 @@
 
 __author__ = """Laurent Kislaire"""
 __email__ = 'teebeenator@gmail.com'
-__version__ = '0.6.0'
+__version__ = '0.10.0'
 
 import sys
 import logging
 import click
-from trawa.main import TorrentWatcher
+from trawa.tw import TorrentWatcher
 
 
 @click.command()
@@ -20,7 +20,7 @@ from trawa.main import TorrentWatcher
 @click.option('--verbose/--no-verbose', help='Show events (default False)')
 def main(config, quiet, verbose):
     """Monitor directories for torrents"""
-    print("Starting trawa version {}".format(__version__))
+    print("Starting TraWa version {}".format(__version__))
     tw = TorrentWatcher(conf_name=config,
                         log_level=logging.WARNING if quiet
                         else logging.DEBUG if verbose
